@@ -1,6 +1,6 @@
 package PDL::DSP::Windows;
 
-our $VERSION = '0.008002'; # TRIAL
+our $VERSION = '0.008003'; # TRIAL
 
 use strict;
 use warnings;
@@ -17,13 +17,10 @@ use PDL::Ufunc ();
 
 # These constants are deleted at the end of this package
 use constant {
-    HAVE_LinearAlgebra => eval { require PDL::LinearAlgebra::Special; 1 } || 0,
-    HAVE_BESSEL        => eval { require PDL::GSLSF::BESSEL; 1 }          || 0,
-    HAVE_GNUPLOT       => eval { require PDL::Graphics::Gnuplot; 1 }      || 0,
-    USE_FFTW_DIRECTION => do {
-        require version;
-        version->parse($PDL::VERSION) <= version->parse('2.007');
-    },
+    HAVE_LinearAlgebra => eval { require PDL::LinearAlgebra::Special } || 0,
+    HAVE_BESSEL        => eval { require PDL::GSLSF::BESSEL }          || 0,
+    HAVE_GNUPLOT       => eval { require PDL::Graphics::Gnuplot }      || 0,
+    USE_FFTW_DIRECTION => version->parse($PDL::VERSION) <= v2.007,
 };
 
 # These constants are left in our namespace for historical reasons
@@ -2041,12 +2038,12 @@ sub cos_mult_to_pow {
 }
 
 # Delete internal constants from namespace
-delete $PDL::DSP::Windows::{$_} for qw(
+delete @PDL::DSP::Windows::{qw(
     HAVE_LinearAlgebra
     HAVE_BESSEL
     HAVE_GNUPLOT
     USE_FFTW_DIRECTION
-);
+)};
 
 1;
 
